@@ -18,8 +18,8 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <gtk/gtk.h>
+#include <gtkdatabox.h>
 
-#include "gtkdatabox.h"
 #include "auxiliar.h"
 #include "main.h"
 #include "translation.h"
@@ -126,7 +126,7 @@ on_combobox_language_changed (GtkComboBox *cmb, gpointer user_data)
 
 	if (callbacks_shield)
 		return;
-	tmp = gtk_combo_box_get_active_text (cmb);
+	tmp = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (cmb));
 	trans_change_language (tmp);
 	g_free (tmp);
 
@@ -161,7 +161,7 @@ on_combobox_kbd_variant_changed (GtkComboBox *cmb, gpointer user_data)
 	if (callbacks_shield)
 		return;
 
-	tmp = gtk_combo_box_get_active_text (cmb);
+	tmp = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (cmb));
 	if (g_str_equal (tmp, KEYB_EDIT))
 		keyb_mode_edit ();
 	else
@@ -179,7 +179,7 @@ on_combobox_kbd_variant_changed (GtkComboBox *cmb, gpointer user_data)
 }
 
 G_MODULE_EXPORT void
-on_window_main_destroy (GtkObject *obj, gpointer data)
+on_window_main_destroy (GtkWidget *obj, gpointer data)
 {
 	if (callbacks_shield)
 		return;
@@ -202,6 +202,28 @@ on_button_info_return_clicked (GtkButton *but, gpointer user_data)
 /**********************************************************************
  * 3 - Tutor window
  **********************************************************************/
+#define CB_COLOR_TAG(TAG, FGCOLOR, BGCOLOR) \
+	if (main_preferences_exist ("colors", TAG "_fg"))\
+		color_fg = main_preferences_get_string ("colors", TAG "_fg");\
+	else\
+	{\
+		color_fg = g_strdup (FGCOLOR);\
+		main_preferences_set_string ("colors", TAG "_fg", color_fg);\
+	}\
+	if (main_preferences_exist ("colors", TAG "_bg"))\
+		color_bg = main_preferences_get_string ("colors", TAG "_bg");\
+	else\
+	{\
+		color_bg = g_strdup (BGCOLOR);\
+		main_preferences_set_string ("colors", TAG "_bg", color_bg);\
+	}\
+	gtk_text_buffer_create_tag (buf, TAG,\
+		       	"foreground", color_fg,\
+		       	"background", color_bg,\
+		       	"underline", PANGO_UNDERLINE_NONE, NULL);\
+	g_free (color_bg);\
+	g_free (color_fg);
+
 G_MODULE_EXPORT void
 on_text_tutor_realize (GtkWidget * widget, gpointer user_data)
 {
@@ -216,9 +238,11 @@ on_text_tutor_realize (GtkWidget * widget, gpointer user_data)
 	GtkWidget *wg;
 	GtkTextBuffer *buf;
 	PangoFontDescription *font_desc;
-	GdkColor color;
+	GdkRGBA color;
 
-	/* Set main color for tutor text (char_untouched)
+	buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
+
+	/* Set main color for tutor text (char_untouched & CIA)
 	 */
 	if (main_preferences_exist ("colors", "char_untouched_bg"))
 		color_main_bg = main_preferences_get_string ("colors", "char_untouched_bg");
@@ -228,11 +252,10 @@ on_text_tutor_realize (GtkWidget * widget, gpointer user_data)
 		color_main_fg = main_preferences_get_string ("colors", "char_untouched_fg");
 	else
 		color_main_fg = g_strdup (TUTOR_BLACK);
+
 	/*
 	 * Colors of text on the tutor window (note: ordering here matters, the first tag created is in the bottom!)
 	 */
-	buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
-
 	gtk_text_buffer_create_tag (buf, "char_keep_wrap",
 		       	"background", color_main_bg,
 		       	"foreground", color_main_fg,
@@ -243,90 +266,12 @@ on_text_tutor_realize (GtkWidget * widget, gpointer user_data)
 		       	"foreground", color_main_fg,
 		       	"underline", PANGO_UNDERLINE_NONE, NULL);
 
-	gtk_text_buffer_create_tag (buf, "char_untouched",
-		       	"background", color_main_bg,
-		       	"foreground", color_main_fg,
-		       	"underline", PANGO_UNDERLINE_NONE, NULL);
-
-	/* char_wrong */
-	if (main_preferences_exist ("colors", "char_wrong_bg"))
-		color_bg = main_preferences_get_string ("colors", "char_wrong_bg");
-	else
-		color_bg = g_strdup (TUTOR_RED_LITE);
-	if (main_preferences_exist ("colors", "char_wrong_fg"))
-		color_fg = main_preferences_get_string ("colors", "char_wrong_fg");
-	else
-		color_fg = g_strdup (TUTOR_RED);
-	gtk_text_buffer_create_tag (buf, "char_wrong",
-		       	"background", color_bg,
-		       	"foreground", color_fg,
-		       	"underline", PANGO_UNDERLINE_NONE, NULL);
-	g_free (color_bg);
-	g_free (color_fg);
-
-	/* char_correct */
-	if (main_preferences_exist ("colors", "char_correct_bg"))
-		color_bg = main_preferences_get_string ("colors", "char_correct_bg");
-	else
-		color_bg = g_strdup (TUTOR_CREAM);
-	if (main_preferences_exist ("colors", "char_correct_fg"))
-		color_fg = main_preferences_get_string ("colors", "char_correct_fg");
-	else
-		color_fg = g_strdup (TUTOR_GREEN);
-	gtk_text_buffer_create_tag (buf, "char_correct",
-		       	"background", color_bg,
-		       	"foreground", color_fg,
-		       	"underline", PANGO_UNDERLINE_NONE, NULL);
-	g_free (color_bg);
-	g_free (color_fg);
-
-	/* char_retouched */
-	if (main_preferences_exist ("colors", "char_retouched_bg"))
-		color_bg = main_preferences_get_string ("colors", "char_retouched_bg");
-	else
-		color_bg = g_strdup (TUTOR_GRAY);
-	if (main_preferences_exist ("colors", "char_retouched_fg"))
-		color_fg = main_preferences_get_string ("colors", "char_retouched_fg");
-	else
-		color_fg = g_strdup (TUTOR_BROWN);
-	gtk_text_buffer_create_tag (buf, "char_retouched",
-			    "background", color_bg,
-			    "foreground", color_fg,
-			    "underline", PANGO_UNDERLINE_NONE, NULL);
-	g_free (color_bg);
-	g_free (color_fg);
-
-	/* cursor_blink */
-	if (main_preferences_exist ("colors", "cursor_blink_bg"))
-		color_bg = main_preferences_get_string ("colors", "cursor_blink_bg");
-	else
-		color_bg = g_strdup (TUTOR_YELLOW);
-	if (main_preferences_exist ("colors", "cursor_blink_fg"))
-		color_fg = main_preferences_get_string ("colors", "cursor_blink_fg");
-	else
-		color_fg = g_strdup (TUTOR_BLACK);
-	gtk_text_buffer_create_tag (buf, "cursor_blink",
-			"background", color_bg,
-			"foreground", color_fg,
-			"underline", PANGO_UNDERLINE_NONE, NULL);
-	g_free (color_bg);
-	g_free (color_fg);
-
-	/* text_intro */
-	if (main_preferences_exist ("colors", "text_intro_bg"))
-		color_bg = main_preferences_get_string ("colors", "text_intro_bg");
-	else
-		color_bg = g_strdup (TUTOR_WHITE);
-	if (main_preferences_exist ("colors", "text_intro_fg"))
-		color_fg = main_preferences_get_string ("colors", "text_intro_fg");
-	else
-		color_fg = g_strdup (TUTOR_BLACK);
-	gtk_text_buffer_create_tag (buf, "text_intro",
-		       	"background", color_bg,
-		       	"foreground", color_fg,
-		       	"underline", PANGO_UNDERLINE_NONE, NULL);
-	g_free (color_bg);
-	g_free (color_fg);
+	CB_COLOR_TAG ("char_untouched",	TUTOR_BLACK,	TUTOR_CREAM);
+	CB_COLOR_TAG ("char_wrong", 	TUTOR_RED,	TUTOR_RED_LITE);
+	CB_COLOR_TAG ("char_correct",	TUTOR_GREEN,	TUTOR_CREAM);
+	CB_COLOR_TAG ("char_retouched",	TUTOR_BROWN,	TUTOR_GRAY);
+	CB_COLOR_TAG ("cursor_blink",	TUTOR_BLACK,	TUTOR_YELLOW);
+	CB_COLOR_TAG ("text_intro",	TUTOR_BLACK,	TUTOR_WHITE);
 
 	/* Tutor font */
 	tmp_font = main_preferences_get_string ("tutor", "lesson_font");
@@ -336,6 +281,7 @@ on_text_tutor_realize (GtkWidget * widget, gpointer user_data)
 		main_preferences_set_string ("tutor", "lesson_font", tmp_font);
 	}
 	gtk_text_buffer_create_tag (buf, "lesson_font", "font", tmp_font, NULL);
+	gtk_font_button_set_font_name (GTK_FONT_BUTTON (get_wg ("fontbutton_tutor")), tmp_font);
 
 	/* Change default font throughout the widget */
 	font_desc = pango_font_description_from_string (tmp_font);
@@ -344,12 +290,12 @@ on_text_tutor_realize (GtkWidget * widget, gpointer user_data)
 	pango_font_description_free (font_desc);
 
 	/* Change default background color throughout the widget */
-	gdk_color_parse (color_main_bg, &color);
-	gtk_widget_modify_base (widget, GTK_STATE_INSENSITIVE, &color);
+	gdk_rgba_parse (&color, color_main_bg);
+	gtk_widget_override_background_color (widget, GTK_STATE_FLAG_INSENSITIVE, &color);
 
 	/* Change default text color throughout the widget */
-	gdk_color_parse (color_main_fg, &color);
-	gtk_widget_modify_text (widget, GTK_STATE_INSENSITIVE, &color);
+	gdk_rgba_parse (&color, color_main_fg);
+	gtk_widget_override_color (widget, GTK_STATE_FLAG_INSENSITIVE, &color);
 
 	/* Turns on/off the beeps according to last time
 	 */
@@ -361,18 +307,11 @@ on_text_tutor_realize (GtkWidget * widget, gpointer user_data)
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wg), beep);
 	main_preferences_set_boolean ("tutor", "tutor_beep", beep);
 
-	/* Workaround to extend the editable lessons, from 50 to 60,
-	 * avoiding to change the translatable message in the tooltip.
-	 */
-	tmp = gtk_widget_get_tooltip_text (get_wg ("togglebutton_edit_basic_lesson"));
-	search = g_strstr_len (tmp, -1, "50");
-	if (search)
-		search[0] = '6';
-	gtk_widget_set_tooltip_text (get_wg ("togglebutton_edit_basic_lesson"), tmp);
-	g_free (tmp);
 
 	g_free (color_main_bg);
 	g_free (color_main_fg);
+
+	tutor_init_goals ();
 }
 
 static void
@@ -461,7 +400,7 @@ on_togglebutton_edit_basic_lesson_toggled (GtkToggleButton * togglebutton, gpoin
 
 		tmp_name = g_ucs4_to_utf8 (basic_get_char_set (), -1, NULL, NULL, NULL);
 		gtk_entry_set_text (GTK_ENTRY (wg), g_strstrip (tmp_name));
-		gtk_entry_set_position (GTK_ENTRY (wg), -1);
+		gtk_editable_set_position (GTK_EDITABLE (wg), -1);
 		g_free (tmp_name);
 
 		gtk_widget_set_sensitive (get_wg ("spinbutton_lesson"), FALSE);
@@ -527,26 +466,13 @@ on_button_tutor_top10_clicked (GtkButton * button, gpointer user_data)
 G_MODULE_EXPORT void
 on_button_tutor_show_keyb_clicked (GtkButton * button, gpointer user_data)
 {
-	if (GTK_WIDGET_VISIBLE (get_wg ("window_hints")))
+	if (gtk_widget_get_visible (get_wg ("window_hints")))
 		window_save ("hints");
 	keyb_mode_hint ();
 }
 
 G_MODULE_EXPORT void
-on_button_tutor_font_clicked (gpointer user_data)
-{
-	GtkWidget *wg;
-	gchar *font;
-
-	wg = get_wg ("fontselectiondialog_tutor");
-	font = main_preferences_get_string ("tutor", "lesson_font");
-	gtk_font_selection_dialog_set_font_name (GTK_FONT_SELECTION_DIALOG (wg), font);
- 	gtk_widget_show (wg);
-	g_free (font);
-}
-
-G_MODULE_EXPORT void
-on_fontselectiondialog_tutor_response (GtkDialog * dialog, gint response_id, gpointer user_data)
+on_fontbutton_tutor_font_set (GtkFontButton * fbut, gpointer user_data)
 {
 	GtkWidget *wg;
 	GtkTextBuffer *buf;
@@ -555,18 +481,12 @@ on_fontselectiondialog_tutor_response (GtkDialog * dialog, gint response_id, gpo
 	GtkTextIter end;
 	gchar *tmp_font;
 
-	if (response_id == GTK_RESPONSE_CANCEL)
-		tmp_font = main_preferences_get_string ("tutor", "lesson_font");
-	else
-		tmp_font =
-			g_strdup (gtk_font_selection_dialog_get_font_name
-				  (GTK_FONT_SELECTION_DIALOG (dialog)));
-
+	tmp_font = g_strdup (gtk_font_button_get_font_name (fbut));
 	if (tmp_font == NULL)
 		tmp_font = g_strdup (LESSON_FONT);
-
-	if (response_id == GTK_RESPONSE_OK)
-		main_preferences_set_string ("tutor", "lesson_font", tmp_font);
+	if (strlen (tmp_font) == 0)
+		tmp_font = g_strdup (LESSON_FONT);
+	main_preferences_set_string ("tutor", "lesson_font", tmp_font);
 
 	wg = get_wg ("text_tutor");
 	buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (wg));
@@ -578,9 +498,6 @@ on_fontselectiondialog_tutor_response (GtkDialog * dialog, gint response_id, gpo
 	gtk_text_buffer_apply_tag_by_name (buf, "lesson_font", &start, &end);
 
 	g_free (tmp_font);
-
-	if (response_id != GTK_RESPONSE_APPLY)
-		gtk_widget_hide (get_wg ("fontselectiondialog_tutor"));
 }
 
 G_MODULE_EXPORT void
@@ -609,23 +526,22 @@ G_MODULE_EXPORT void
 on_button_tutor_back_clicked (GtkButton *button, gpointer user_data)
 {
 	window_save ("tutor");
-	if (GTK_WIDGET_VISIBLE (get_wg ("window_hints")))
+	if (gtk_widget_get_visible (get_wg ("window_hints")))
 		window_save ("hints");
-	if (GTK_WIDGET_VISIBLE (get_wg ("window_top10")))
+	if (gtk_widget_get_visible (get_wg ("window_top10")))
 		window_save ("top10");
-	if (GTK_WIDGET_VISIBLE (get_wg ("window_stat")))
+	if (gtk_widget_get_visible (get_wg ("window_stat")))
 		window_save ("stat");
 	gtk_widget_hide (get_wg ("window_tutor"));
 	gtk_widget_hide (get_wg ("window_hints"));
 	gtk_widget_hide (get_wg ("window_top10"));
 	gtk_widget_hide (get_wg ("window_stat"));
 	gtk_widget_hide (get_wg ("filechooser_tutor"));
-	gtk_widget_hide (get_wg ("fontselectiondialog_tutor"));
 	gtk_widget_show (get_wg ("window_main"));
 }
 
 G_MODULE_EXPORT void
-on_window_tutor_destroy (GtkObject * object, gpointer user_data)
+on_window_tutor_destroy (GtkWidget * object, gpointer user_data)
 {
 	if (callbacks_shield)
 		return;
@@ -799,7 +715,7 @@ on_combobox_top10_language_changed (GtkComboBox *cmb, gpointer user_data)
 
 	if (callbacks_shield)
 		return;
-	tmp = gtk_combo_box_get_active_text (cmb);
+	tmp = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (cmb));
 	trans_change_language (tmp);
 	g_free (tmp);
 
@@ -915,7 +831,7 @@ on_combobox_keyboard_country_changed (GtkComboBox *cmb, gpointer user_data)
 		return;
 
 	keyb_set_combo_kbd_variant ("combobox_keyboard_country", "combobox_keyboard_variant");
-	tmp = gtk_combo_box_get_active_text (cmb);
+	tmp = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (cmb));
 	if (g_str_equal (tmp, KEYB_CUSTOM) &&
 		gtk_combo_box_get_active ( GTK_COMBO_BOX (get_wg ("combobox_keyboard_variant")) ) > -1 )
 	{
@@ -936,7 +852,7 @@ on_combobox_keyboard_variant_changed (GtkComboBox *cmb, gpointer user_data)
 
 	keyb_update_from_variant ("combobox_keyboard_country", "combobox_keyboard_variant");
 
-	tmp = gtk_combo_box_get_active_text (GTK_COMBO_BOX (get_wg ("combobox_keyboard_country")));
+	tmp = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (get_wg ("combobox_keyboard_country")));
 	if (g_str_equal (tmp, KEYB_CUSTOM) &&
 		gtk_combo_box_get_active (cmb) > -1 )
 
@@ -981,7 +897,7 @@ on_button_kb_save_clicked (GtkButton * button, gpointer user_data)
 	keyb_set_name (tmp);
 	g_free (tmp);
 
-	gtk_label_set (GTK_LABEL (get_wg ("label_confirm_action")), "OVERWRITE");
+	gtk_label_set_text (GTK_LABEL (get_wg ("label_confirm_action")), "OVERWRITE");
 	if (g_file_test (tmp_path, G_FILE_TEST_IS_REGULAR))
 		gtk_widget_show (get_wg ("dialog_confirm"));
 	else
@@ -1011,8 +927,8 @@ on_button_keyboard_close_clicked (GtkButton *but, gpointer user_data)
 G_MODULE_EXPORT void
 on_button_keyboard_hands_clicked (GtkButton *but, gpointer user_data)
 {
-	if (GTK_WIDGET_VISIBLE (get_wg ("window_tutor")))
-		if (GTK_WIDGET_VISIBLE (get_wg ("hbox_keyboard_hints")))
+	if (gtk_widget_get_visible (get_wg ("window_tutor")))
+		if (gtk_widget_get_visible (get_wg ("hbox_keyboard_hints")))
 		{
 			gtk_widget_show (get_wg ("window_hints"));
 			hints_update_from_char (cursor_get_char ());
@@ -1049,7 +965,7 @@ on_toggle_shift1_toggled (GtkToggleButton * togglebutton, gpointer user_data)
 	keyb_update_virtual_layout ();
 	keyb_edit_none ();
 
-	if (GTK_WIDGET_VISIBLE (get_wg ("hbox_keyboard_hints")))
+	if (gtk_widget_get_visible (get_wg ("hbox_keyboard_hints")))
 		hints_update_from_button (GTK_BUTTON (togglebutton));
 }
 
@@ -1065,7 +981,7 @@ on_toggle_shift2_toggled (GtkToggleButton * togglebutton, gpointer user_data)
 	keyb_update_virtual_layout ();
 	keyb_edit_none ();
 
-	if (GTK_WIDGET_VISIBLE (get_wg ("hbox_keyboard_hints")))
+	if (gtk_widget_get_visible (get_wg ("hbox_keyboard_hints")))
 		hints_update_from_button (GTK_BUTTON (togglebutton));
 }
 
@@ -1093,7 +1009,7 @@ on_virtual_key_grab_focus (GtkWidget *wg, gpointer user_data)
 	if (callbacks_shield)
 		return;
 
-	if ( GTK_WIDGET_VISIBLE (get_wg ("hbox_keyboard_hints")) )
+	if ( gtk_widget_get_visible (get_wg ("hbox_keyboard_hints")) )
 		hints_update_from_button (GTK_BUTTON (wg));
 	else
 		keyb_edit_button (GTK_BUTTON (wg));
@@ -1105,7 +1021,7 @@ on_virtual_key_clicked (GtkButton * button, gpointer user_data)
 	if (callbacks_shield)
 		return;
 
-	if ( GTK_WIDGET_VISIBLE (get_wg ("hbox_keyboard_hints")) )
+	if ( gtk_widget_get_visible (get_wg ("hbox_keyboard_hints")) )
 		hints_update_from_button (button);
 	else
 		keyb_edit_button (button);
@@ -1303,12 +1219,12 @@ on_combobox_stat_module_changed (GtkComboBox *cmb, gpointer user_data)
 
 	callbacks_shield_set (TRUE);
 	for (i = 0; i < 4; i++)
-		gtk_combo_box_remove_text (GTK_COMBO_BOX (get_wg ("combobox_stat_type")), 0);
+		gtk_combo_box_text_remove (GTK_COMBO_BOX_TEXT (get_wg ("combobox_stat_type")), 0);
 	tmp = g_strdup_printf ("%s (%%)", _("Accuracy"));
-	gtk_combo_box_insert_text (GTK_COMBO_BOX (get_wg ("combobox_stat_type")), 0, tmp);
+	gtk_combo_box_text_insert_text (GTK_COMBO_BOX_TEXT (get_wg ("combobox_stat_type")), 0, tmp);
 	g_free (tmp);
 	tmp = g_strdup_printf ("%s %s", _("Speed"), _("(WPM)"));
-	gtk_combo_box_insert_text (GTK_COMBO_BOX (get_wg ("combobox_stat_type")), 1, tmp);
+	gtk_combo_box_text_insert_text (GTK_COMBO_BOX_TEXT (get_wg ("combobox_stat_type")), 1, tmp);
 	g_free (tmp);
 
 	switch (gtk_combo_box_get_active (cmb))
@@ -1319,10 +1235,10 @@ on_combobox_stat_module_changed (GtkComboBox *cmb, gpointer user_data)
 	case 1:
 		win_title = g_strdup_printf ("%s (%s)", stat_title, keyb_mode_get_name ());
 		tmp = g_strdup_printf ("%s", _("Errors"));
-		gtk_combo_box_insert_text (GTK_COMBO_BOX (get_wg ("combobox_stat_type")), 2, tmp);
+		gtk_combo_box_text_insert_text (GTK_COMBO_BOX_TEXT (get_wg ("combobox_stat_type")), 2, tmp);
 		g_free (tmp);
 		tmp = g_strdup_printf ("%s", _("Touch times (s)"));
-		gtk_combo_box_insert_text (GTK_COMBO_BOX (get_wg ("combobox_stat_type")), 3, tmp);
+		gtk_combo_box_text_insert_text (GTK_COMBO_BOX_TEXT (get_wg ("combobox_stat_type")), 3, tmp);
 		g_free (tmp);
 		break;
 	case 2:
@@ -1331,10 +1247,10 @@ on_combobox_stat_module_changed (GtkComboBox *cmb, gpointer user_data)
 	case 3:
 		win_title = g_strdup_printf ("%s (%s)", stat_title, trans_get_current_language ());
 		tmp = g_strdup_printf ("%s (%%)", _("Fluidity"));
-		gtk_combo_box_insert_text (GTK_COMBO_BOX (get_wg ("combobox_stat_type")), 2, tmp);
+		gtk_combo_box_text_insert_text (GTK_COMBO_BOX_TEXT (get_wg ("combobox_stat_type")), 2, tmp);
 		g_free (tmp);
 		tmp = g_strdup_printf ("%s (0-10)", _("Score"));
-		gtk_combo_box_insert_text (GTK_COMBO_BOX (get_wg ("combobox_stat_type")), 3, tmp);
+		gtk_combo_box_text_insert_text (GTK_COMBO_BOX_TEXT (get_wg ("combobox_stat_type")), 3, tmp);
 		g_free (tmp);
 		break;
 	default:
