@@ -50,17 +50,20 @@ trans_code_to_country (gchar *code)
 		{"bg","България"},
 		{"br","Brasil"},
 		{"ca","Canada"},
+		{"ch","Schweiz / Suisse"},
+		{"cn","中华人民共和国"},
 		{"cz","Česká republika"},
-		{"dk","Danmark"},
+		{"dk","Danmark"}, /* 10 */
 		{"de","Deutschland"},
 		{"eo","Esperantujo"},
 		{"es","España"},
 		{"eu","Euskal Herria"},
+		{"fi","Suomi"},
 		{"fr","France"},
 		{"gr","Ελλάδα"},
 		{"il","ישראל"},
 		{"hu","Magyarország"},
-		{"it","Italia"},
+		{"it","Italia"}, /* 20 */
 		{"jp","日本 (Nippon)"},
 		{"kk","Қазақстан"},
 		{"no","Norge"},
@@ -70,12 +73,9 @@ trans_code_to_country (gchar *code)
 		{"ru","Россия"},
 		{"se","Sverige"},
 		{"tr","Türkiye"},
-		{"ua","Україна"},
+		{"ua","Україна"}, /* 30 */
 		{"uk","United Kingdom"},
 		{"us","USA"},
-		{"cn","中华人民共和国"},
-		{"ch","Schweiz / Suisse"},
-		{"",""},
 		{"",""},
 		{"",""},
 		{"",""},
@@ -348,9 +348,8 @@ trans_init_language_env ()
 	if (lang_ok == FALSE)
 	{
 		g_free (tmp_code);
-		//tmp_code = g_strdup ("eo");
 		tmp_code = g_strdup ("C");
-		g_message ("as your prefered locales aren't available, "
+		g_message ("as your preferred locale isn't available, "
 			       "we are using this neutral one: \"%s\"", tmp_code);
 	}
 
@@ -379,17 +378,19 @@ trans_set_combo_language ()
 		cmb = GTK_COMBO_BOX (get_wg ("combobox_language"));
 
 	tmp_code = main_preferences_get_string ("interface", "language");
-	if (tmp_code == NULL)
+	if (tmp_code == NULL || g_str_equal ("en_US", tmp_code))
 	{
-		g_message ("NULL language code detected. So, using \"C\".");
+		g_message ("Using \"C\" as language code.");
 		main_preferences_set_string ("interface", "language", "C");
+		if (tmp_code)
+			g_free (tmp_code);
 		tmp_code = g_strdup ("C");
 	}
-	gtk_combo_box_remove_text (cmb, 0);
+	gtk_combo_box_text_remove (GTK_COMBO_BOX_TEXT (cmb), 0);
 	for (i = 0, i_env = -1; i < lang_num; i++)
 	{
 		langcode = g_strdup_printf ("%s (%s)", lang[i].name, lang[i].code);
-		gtk_combo_box_append_text (cmb, langcode);
+		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (cmb), langcode);
 		if (g_str_equal (lang[i].code, tmp_code))
 			i_env = i;
 		else if (g_str_has_prefix (tmp_code, lang[i].code))
@@ -415,12 +416,7 @@ trans_set_combo_language ()
 	}
 	recur = FALSE;
 
-	if (tmp_code[0] == 'C')
-	{
-		g_free (tmp_code);
-		tmp_code = g_strdup ("en");
-	}
-	if (tmp_code[0] == _("en")[0] && tmp_code[1] == _("en")[1])
+	if (g_str_has_prefix (tmp_code, "en") || g_str_equal (tmp_code, "C"))
 		gtk_widget_show (get_wg ("checkbutton_speech"));
 	else
 		gtk_widget_hide (get_wg ("checkbutton_speech"));
@@ -614,7 +610,6 @@ trans_read_text (const gchar * file_end)
 "We do aim to develop the skill of typing, making it an automatic reflex akin to the acts of walking, talking, etc. "
 "After reaching this goal, the act of typing will become automatic and require little concentration. "
 "Then you will be able to pay attention to the real meaning of the text.");
-	/* English typo: minimun -> minimum */
 	gchar *fluid3 = _("These exercises are longer. Each exercise consists of three paragraphs and "
 "the emphasis is placed on correctness and rhythm, with a minimum speed requirement. "
 "Here you will be required to use the backspace key to correct any mistakes. "
