@@ -53,6 +53,44 @@ struct
 	gint correcting;
 } tutor;
 
+struct
+{
+	struct
+	{
+		double accuracy;
+		double speed;
+	} basic;
+	struct
+	{
+		double accuracy;
+		double speed;
+		double accuracy_learning;
+		double accuracy_improving;
+		double accuracy_reaching;
+	} adapt;
+	struct
+	{
+		double accuracy;
+		double speed;
+		double speed_crawling;
+		double speed_stepping;
+		double speed_walking;
+		double speed_jogging;
+		double speed_running;
+		double speed_professional;
+		double speed_racer;
+		double speed_flying;
+	} velo;
+	struct
+	{
+		double accuracy;
+		double speed;
+		double fluidity;
+		double fluidity_stumbling;
+		double speed_flying;
+	} fluid;
+} goal;
+
 extern gchar *OTHER_DEFAULT;
 
 /*******************************************************************************
@@ -98,15 +136,89 @@ tutor_init_timers ()
 	tutor.tmr = g_timer_new ();
 }
 
+#define GOAL_GSET(MODULE, GOAL, DEFAULT_VAL) \
+	if (main_preferences_exist ("goals", #MODULE "_" #GOAL))\
+		goal.MODULE.GOAL = (gdouble) main_preferences_get_int ("goals", #MODULE "_" #GOAL);\
+	else\
+	{\
+		goal.MODULE.GOAL = DEFAULT_VAL;\
+		main_preferences_set_int ("goals", #MODULE "_" #GOAL, DEFAULT_VAL);\
+	}
+#define LEVEL_GSET(MODULE, GOAL, DEFAULT_VAL) \
+	if (main_preferences_exist ("levels", #MODULE "_" #GOAL))\
+		goal.MODULE.GOAL = (gdouble) main_preferences_get_int ("levels", #MODULE "_" #GOAL);\
+	else\
+	{\
+		goal.MODULE.GOAL = DEFAULT_VAL;\
+		main_preferences_set_int ("levels", #MODULE "_" #GOAL, DEFAULT_VAL);\
+	}
+void
+tutor_init_goals ()
+{
+	GOAL_GSET (basic, accuracy, 95);
+	GOAL_GSET (basic, speed, 10);
+	GOAL_GSET (adapt, accuracy, 98);
+	GOAL_GSET (adapt, speed, 10);
+	GOAL_GSET (velo, accuracy, 95);
+	GOAL_GSET (velo, speed, 50);
+	GOAL_GSET (fluid, accuracy, 97);
+	GOAL_GSET (fluid, speed, 50);
+	GOAL_GSET (fluid, fluidity, 70);
+
+	LEVEL_GSET (adapt, accuracy_learning, 50);
+	LEVEL_GSET (adapt, accuracy_improving, 90);
+	LEVEL_GSET (adapt, accuracy_reaching, 95);
+
+	LEVEL_GSET (velo, speed_crawling, 10);
+	LEVEL_GSET (velo, speed_stepping, 20);
+	LEVEL_GSET (velo, speed_walking, 30);
+	LEVEL_GSET (velo, speed_jogging, 40);
+	LEVEL_GSET (velo, speed_running, 60);
+	LEVEL_GSET (velo, speed_professional, 70);
+	LEVEL_GSET (velo, speed_racer, 80);
+	LEVEL_GSET (velo, speed_flying, 90);
+
+	LEVEL_GSET (fluid, fluidity_stumbling, 60);
+	LEVEL_GSET (fluid, speed_flying, 90);
+
+	/*
+	g_printf ("basic accur: %.0f\n", goal.basic.accuracy);
+	g_printf ("basic speed: %.0f\n", goal.basic.speed);
+	g_printf ("adapt accur: %.0f\n", goal.adapt.accuracy);
+	g_printf ("adapt speed: %.0f\n", goal.adapt.speed);
+	g_printf ("velo accur: %.0f\n", goal.velo.accuracy);
+	g_printf ("velo speed: %.0f\n", goal.velo.speed);
+	g_printf ("fluid accur: %.0f\n", goal.fluid.accuracy);
+	g_printf ("fluid speed: %.0f\n", goal.fluid.speed);
+	g_printf ("fluid fluidity: %.0f\n", goal.fluid.fluidity);
+
+	g_printf ("adapt learning: %.0f\n", goal.adapt.accuracy_learning);
+	g_printf ("adapt improving: %.0f\n", goal.adapt.accuracy_improving);
+	g_printf ("adapt reaching: %.0f\n", goal.adapt.accuracy_reaching);
+
+	g_printf ("velo crawling: %.0f\n", goal.velo.speed_crawling);
+	g_printf ("velo stepping: %.0f\n", goal.velo.speed_stepping);
+	g_printf ("velo walking: %.0f\n", goal.velo.speed_walking);
+	g_printf ("velo jogging: %.0f\n", goal.velo.speed_jogging);
+	g_printf ("velo running: %.0f\n", goal.velo.speed_running);
+	g_printf ("velo professional: %.0f\n", goal.velo.speed_professional);
+	g_printf ("velo racer: %.0f\n", goal.velo.speed_racer);
+	g_printf ("velo flying: %.0f\n", goal.velo.speed_flying);
+
+	g_printf ("fluid stumbling: %.0f\n", goal.fluid.fluidity_stumbling);
+	g_printf ("fluid flying: %.0f\n", goal.fluid.speed_flying);
+	 */
+}
+
 gdouble
 tutor_goal_accuracy ()
 {
 	switch (tutor.type)
 	{
-		case TT_BASIC: return 95.0;
-		case TT_ADAPT: return 98.0;
-		case TT_VELO: return 95.0;
-		case TT_FLUID: return 97.0;
+		case TT_BASIC: return goal.basic.accuracy;
+		case TT_ADAPT: return goal.adapt.accuracy;
+		case TT_VELO: return goal.velo.accuracy;
+		case TT_FLUID: return goal.fluid.accuracy;
 	}
 	return -1.0;
 }
@@ -116,10 +228,10 @@ tutor_goal_speed ()
 {
 	switch (tutor.type)
 	{
-		case TT_BASIC: return 10.0;
-		case TT_ADAPT: return 10.0;
-		case TT_VELO: return 50.0;
-		case TT_FLUID: return 50.0;
+		case TT_BASIC: return goal.basic.speed;
+		case TT_ADAPT: return goal.adapt.speed;
+		case TT_VELO: return goal.velo.speed;
+		case TT_FLUID: return goal.fluid.speed;
 	}
 	return -1.0;
 }
@@ -132,11 +244,23 @@ tutor_goal_fluidity ()
 		case TT_BASIC:
 		case TT_ADAPT:
 		case TT_VELO: return 0.0;
-		case TT_FLUID: return 70.0;
+		case TT_FLUID: return goal.fluid.fluidity;
 	}
 	return -1.0;
 }
 
+gdouble
+tutor_goal_level (guint n)
+{
+	switch (tutor.type)
+	{
+		case TT_ADAPT: if (n > 2) return -1.0; return (&goal.adapt.accuracy_learning) [n];
+		case TT_VELO: if (n > 7) return -2.0; return (&goal.velo.speed_crawling) [n];
+		case TT_FLUID: if (n > 1) return -3.0; return (&goal.fluid.fluidity_stumbling) [n];
+	}
+	return -4.0;
+}
+
 /**********************************************************************
  * Initialize the course 
  */
@@ -309,7 +433,7 @@ tutor_update_intro ()
 	gchar *tmp_name;
 	gchar *text;
 	gchar *color_bg;
-	GdkColor color;
+	GdkRGBA color;
 	GtkWidget *wg;
 	GtkLabel *wg_label;
 	GtkTextView *wg_text;
@@ -347,8 +471,8 @@ tutor_update_intro ()
 		color_bg = main_preferences_get_string ("colors", "text_intro_bg");
 	else
 		color_bg = g_strdup (TUTOR_WHITE);
-	gdk_color_parse (color_bg, &color);
-	gtk_widget_modify_base (get_wg ("text_tutor"), GTK_STATE_INSENSITIVE, &color);
+	gdk_rgba_parse (&color, color_bg);
+	gtk_widget_override_background_color (get_wg ("text_tutor"), GTK_STATE_FLAG_INSENSITIVE, &color);
 	g_free (color_bg);
 
 	wg = get_wg ("scrolledwindow_tutor_main");
@@ -366,7 +490,7 @@ tutor_update_start ()
 	gchar *tmp_name;
 	gchar *text;
 	gchar *color_bg;
-	GdkColor color;
+	GdkRGBA color;
 	GtkWidget *wg;
 	GtkTextBuffer *buf;
 	GtkTextIter start;
@@ -418,13 +542,16 @@ tutor_update_start ()
 		color_bg = main_preferences_get_string ("colors", "char_untouched_bg");
 	else
 		color_bg = g_strdup (TUTOR_CREAM);
-	gdk_color_parse (color_bg, &color);
-	gtk_widget_modify_base (get_wg ("text_tutor"), GTK_STATE_INSENSITIVE, &color);
+	gdk_rgba_parse (&color, color_bg);
+	gtk_widget_override_background_color (get_wg ("text_tutor"), GTK_STATE_FLAG_INSENSITIVE, &color);
 	g_free (color_bg);
 
 	gtk_text_buffer_get_bounds (buf, &start, &end);
 	gtk_text_iter_backward_char (&end);
 	gtk_text_buffer_apply_tag_by_name (buf, "lesson_font", &start, &end);
+
+	/* Trying to minimize automatic wrapping because of cursor blinking:
+	*/
 	end = start;
 	while (gtk_text_iter_forward_word_end (&end))
 	{
@@ -1083,7 +1210,8 @@ tutor_calc_stats ()
 	wg = get_wg ("text_tutor");
 	buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (wg));
 
-	// Begin the accuracy
+	/* Begin the accuracy */
+	;
 	tmp_str = g_strconcat ("\n", _("STATISTICS"), "\n",
 			       _("Elapsed time:"), " %i ",
 			       dngettext (PACKAGE, "minute and", "minutes and", minutes),
@@ -1094,7 +1222,7 @@ tutor_calc_stats ()
 	g_free (tmp_str);
 	gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
 
-	// Paint the accuracy
+	/* Paint the accuracy */
 	g_free (tmp_str2);
 	tmp_str2 = g_strdup_printf ("%.1f%%", accuracy);
 	gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
@@ -1568,7 +1696,7 @@ tutor_beep ()
 	GtkWidget *wg;
 
 	wg = get_wg ("togglebutton_tutor_beep");
-	if ((GTK_TOGGLE_BUTTON (wg))->active)
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wg)))
 		gdk_beep ();
 }
 
@@ -1588,7 +1716,7 @@ tutor_speak_string (gchar *string, gboolean wait)
 
 	if (espeak_OK == FALSE)
 		return;
-	if (!GTK_WIDGET_VISIBLE (wg) )
+	if (!gtk_widget_get_visible (wg) )
 		return;
 	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wg)) )
 		return;
